@@ -189,6 +189,9 @@ main(void)
     assert(test_casestring("Thorn", 0x00fe));
     assert(test_casestring("thorn", 0x00fe));
 
+    assert(test_string("", XKB_KEY_NoSymbol));
+    assert(test_casestring("", XKB_KEY_NoSymbol));
+
     assert(test_utf8(XKB_KEY_y, "y"));
     assert(test_utf8(XKB_KEY_u, "u"));
     assert(test_utf8(XKB_KEY_m, "m"));
@@ -249,6 +252,7 @@ main(void)
     assert(test_utf32_to_keysym(0xd7, XKB_KEY_multiply));
     assert(test_utf32_to_keysym('-', XKB_KEY_minus));
     assert(test_utf32_to_keysym(0x10fffd, 0x110fffd));
+    assert(test_utf32_to_keysym(0x20ac, XKB_KEY_EuroSign));
 
     // Unicode non-characters
     assert(test_utf32_to_keysym(0xfdd0, XKB_KEY_NoSymbol));
